# Version: 0.1.0

* [#2](https://github.com/saadmk11/redis-search-django/pull/2): Bump actions/checkout from 2 to 3
* [#5](https://github.com/saadmk11/redis-search-django/pull/5): Create LICENSE
* [#4](https://github.com/saadmk11/redis-search-django/pull/4): Add Tests and Improvements
